Coverage for nexios\websockets\__init__.py: 100%

1 from .base import WebSocket, WebSocketDisconnect # type:ignore

2 from .channels import Channel, ChannelBox

3 from .consumers import WebSocketConsumer

4 import typing

5

6 Scope = typing.MutableMapping[str, typing.Any]

7 Message = typing.MutableMapping[str, typing.Any]

8

9 Receive = typing.Callable[[], typing.Awaitable[Message]]

10 Send = typing.Callable[[Message], typing.Awaitable[None]]

11

12

13 __all__ = [

14 "WebSocket",

15 "Channel",

16 "ChannelBox",

17 "WebSocketConsumer",

18 "WebSocketDisconnect",

19]